@@ -4,16 +4,14 @@ Main interface for compute-optimizer service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_compute_optimizer import (
         Client,
         ComputeOptimizerClient,
     )
 
-    session = boto3.Session()
-
-    client: ComputeOptimizerClient = boto3.client("compute-optimizer")
-    session_client: ComputeOptimizerClient = session.client("compute-optimizer")
+    session = Session()
+    client: ComputeOptimizerClient = session.client("compute-optimizer")
     ```
 """
 from .client import ComputeOptimizerClient
