@@ -1,7 +1,7 @@
 """
 Type annotations for compute-optimizer service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/type_defs/)
 
 Usage::
 
@@ -141,82 +141,100 @@ __all__ = (
 AccountEnrollmentStatusTypeDef = TypedDict(
     "AccountEnrollmentStatusTypeDef",
     {
-        "accountId": NotRequired[str],
-        "status": NotRequired[StatusType],
-        "statusReason": NotRequired[str],
-        "lastUpdatedTimestamp": NotRequired[datetime],
+        "accountId": str,
+        "status": StatusType,
+        "statusReason": str,
+        "lastUpdatedTimestamp": datetime,
     },
+    total=False,
 )
 
 AutoScalingGroupConfigurationTypeDef = TypedDict(
     "AutoScalingGroupConfigurationTypeDef",
     {
-        "desiredCapacity": NotRequired[int],
-        "minSize": NotRequired[int],
-        "maxSize": NotRequired[int],
-        "instanceType": NotRequired[str],
+        "desiredCapacity": int,
+        "minSize": int,
+        "maxSize": int,
+        "instanceType": str,
     },
+    total=False,
 )
 
 AutoScalingGroupRecommendationOptionTypeDef = TypedDict(
     "AutoScalingGroupRecommendationOptionTypeDef",
     {
-        "configuration": NotRequired["AutoScalingGroupConfigurationTypeDef"],
-        "projectedUtilizationMetrics": NotRequired[List["UtilizationMetricTypeDef"]],
-        "performanceRisk": NotRequired[float],
-        "rank": NotRequired[int],
-        "savingsOpportunity": NotRequired["SavingsOpportunityTypeDef"],
-        "migrationEffort": NotRequired[MigrationEffortType],
+        "configuration": "AutoScalingGroupConfigurationTypeDef",
+        "projectedUtilizationMetrics": List["UtilizationMetricTypeDef"],
+        "performanceRisk": float,
+        "rank": int,
+        "savingsOpportunity": "SavingsOpportunityTypeDef",
+        "migrationEffort": MigrationEffortType,
     },
+    total=False,
 )
 
 AutoScalingGroupRecommendationTypeDef = TypedDict(
     "AutoScalingGroupRecommendationTypeDef",
     {
-        "accountId": NotRequired[str],
-        "autoScalingGroupArn": NotRequired[str],
-        "autoScalingGroupName": NotRequired[str],
-        "finding": NotRequired[FindingType],
-        "utilizationMetrics": NotRequired[List["UtilizationMetricTypeDef"]],
-        "lookBackPeriodInDays": NotRequired[float],
-        "currentConfiguration": NotRequired["AutoScalingGroupConfigurationTypeDef"],
-        "recommendationOptions": NotRequired[List["AutoScalingGroupRecommendationOptionTypeDef"]],
-        "lastRefreshTimestamp": NotRequired[datetime],
-        "currentPerformanceRisk": NotRequired[CurrentPerformanceRiskType],
-        "effectiveRecommendationPreferences": NotRequired[
-            "EffectiveRecommendationPreferencesTypeDef"
-        ],
-        "inferredWorkloadTypes": NotRequired[List[InferredWorkloadTypeType]],
+        "accountId": str,
+        "autoScalingGroupArn": str,
+        "autoScalingGroupName": str,
+        "finding": FindingType,
+        "utilizationMetrics": List["UtilizationMetricTypeDef"],
+        "lookBackPeriodInDays": float,
+        "currentConfiguration": "AutoScalingGroupConfigurationTypeDef",
+        "recommendationOptions": List["AutoScalingGroupRecommendationOptionTypeDef"],
+        "lastRefreshTimestamp": datetime,
+        "currentPerformanceRisk": CurrentPerformanceRiskType,
+        "effectiveRecommendationPreferences": "EffectiveRecommendationPreferencesTypeDef",
+        "inferredWorkloadTypes": List[InferredWorkloadTypeType],
     },
+    total=False,
 )
 
 CurrentPerformanceRiskRatingsTypeDef = TypedDict(
     "CurrentPerformanceRiskRatingsTypeDef",
     {
-        "high": NotRequired[int],
-        "medium": NotRequired[int],
-        "low": NotRequired[int],
-        "veryLow": NotRequired[int],
+        "high": int,
+        "medium": int,
+        "low": int,
+        "veryLow": int,
     },
+    total=False,
 )
 
-DeleteRecommendationPreferencesRequestRequestTypeDef = TypedDict(
-    "DeleteRecommendationPreferencesRequestRequestTypeDef",
+_RequiredDeleteRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteRecommendationPreferencesRequestRequestTypeDef",
     {
         "resourceType": ResourceTypeType,
         "recommendationPreferenceNames": Sequence[RecommendationPreferenceNameType],
-        "scope": NotRequired["ScopeTypeDef"],
     },
 )
+_OptionalDeleteRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteRecommendationPreferencesRequestRequestTypeDef",
+    {
+        "scope": "ScopeTypeDef",
+    },
+    total=False,
+)
+
+
+class DeleteRecommendationPreferencesRequestRequestTypeDef(
+    _RequiredDeleteRecommendationPreferencesRequestRequestTypeDef,
+    _OptionalDeleteRecommendationPreferencesRequestRequestTypeDef,
+):
+    pass
+
 
 DescribeRecommendationExportJobsRequestRequestTypeDef = TypedDict(
     "DescribeRecommendationExportJobsRequestRequestTypeDef",
     {
-        "jobIds": NotRequired[Sequence[str]],
-        "filters": NotRequired[Sequence["JobFilterTypeDef"]],
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
+        "jobIds": Sequence[str],
+        "filters": Sequence["JobFilterTypeDef"],
+        "nextToken": str,
+        "maxResults": int,
     },
+    total=False,
 )
 
 DescribeRecommendationExportJobsResponseTypeDef = TypedDict(
@@ -231,57 +249,76 @@ DescribeRecommendationExportJobsResponseTypeDef = TypedDict(
 EBSFilterTypeDef = TypedDict(
     "EBSFilterTypeDef",
     {
-        "name": NotRequired[Literal["Finding"]],
-        "values": NotRequired[Sequence[str]],
+        "name": Literal["Finding"],
+        "values": Sequence[str],
     },
+    total=False,
 )
 
 EBSUtilizationMetricTypeDef = TypedDict(
     "EBSUtilizationMetricTypeDef",
     {
-        "name": NotRequired[EBSMetricNameType],
-        "statistic": NotRequired[MetricStatisticType],
-        "value": NotRequired[float],
+        "name": EBSMetricNameType,
+        "statistic": MetricStatisticType,
+        "value": float,
     },
+    total=False,
 )
 
 EffectiveRecommendationPreferencesTypeDef = TypedDict(
     "EffectiveRecommendationPreferencesTypeDef",
     {
-        "cpuVendorArchitectures": NotRequired[List[CpuVendorArchitectureType]],
-        "enhancedInfrastructureMetrics": NotRequired[EnhancedInfrastructureMetricsType],
-        "inferredWorkloadTypes": NotRequired[InferredWorkloadTypesPreferenceType],
+        "cpuVendorArchitectures": List[CpuVendorArchitectureType],
+        "enhancedInfrastructureMetrics": EnhancedInfrastructureMetricsType,
+        "inferredWorkloadTypes": InferredWorkloadTypesPreferenceType,
     },
+    total=False,
 )
 
 EnrollmentFilterTypeDef = TypedDict(
     "EnrollmentFilterTypeDef",
     {
-        "name": NotRequired[Literal["Status"]],
-        "values": NotRequired[Sequence[str]],
+        "name": Literal["Status"],
+        "values": Sequence[str],
     },
+    total=False,
 )
 
 EstimatedMonthlySavingsTypeDef = TypedDict(
     "EstimatedMonthlySavingsTypeDef",
     {
-        "currency": NotRequired[CurrencyType],
-        "value": NotRequired[float],
+        "currency": CurrencyType,
+        "value": float,
     },
+    total=False,
 )
 
-ExportAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
-    "ExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
+_RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
+    "_RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
     {
         "s3DestinationConfig": "S3DestinationConfigTypeDef",
-        "accountIds": NotRequired[Sequence[str]],
-        "filters": NotRequired[Sequence["FilterTypeDef"]],
-        "fieldsToExport": NotRequired[Sequence[ExportableAutoScalingGroupFieldType]],
-        "fileFormat": NotRequired[Literal["Csv"]],
-        "includeMemberAccounts": NotRequired[bool],
-        "recommendationPreferences": NotRequired["RecommendationPreferencesTypeDef"],
     },
 )
+_OptionalExportAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
+    "_OptionalExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
+    {
+        "accountIds": Sequence[str],
+        "filters": Sequence["FilterTypeDef"],
+        "fieldsToExport": Sequence[ExportableAutoScalingGroupFieldType],
+        "fileFormat": Literal["Csv"],
+        "includeMemberAccounts": bool,
+        "recommendationPreferences": "RecommendationPreferencesTypeDef",
+    },
+    total=False,
+)
+
+
+class ExportAutoScalingGroupRecommendationsRequestRequestTypeDef(
+    _RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef,
+    _OptionalExportAutoScalingGroupRecommendationsRequestRequestTypeDef,
+):
+    pass
+
 
 ExportAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
     "ExportAutoScalingGroupRecommendationsResponseTypeDef",
@@ -295,21 +332,36 @@ ExportAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
 ExportDestinationTypeDef = TypedDict(
     "ExportDestinationTypeDef",
     {
-        "s3": NotRequired["S3DestinationTypeDef"],
+        "s3": "S3DestinationTypeDef",
     },
+    total=False,
 )
 
-ExportEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
-    "ExportEBSVolumeRecommendationsRequestRequestTypeDef",
+_RequiredExportEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
+    "_RequiredExportEBSVolumeRecommendationsRequestRequestTypeDef",
     {
         "s3DestinationConfig": "S3DestinationConfigTypeDef",
-        "accountIds": NotRequired[Sequence[str]],
-        "filters": NotRequired[Sequence["EBSFilterTypeDef"]],
-        "fieldsToExport": NotRequired[Sequence[ExportableVolumeFieldType]],
-        "fileFormat": NotRequired[Literal["Csv"]],
-        "includeMemberAccounts": NotRequired[bool],
     },
 )
+_OptionalExportEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
+    "_OptionalExportEBSVolumeRecommendationsRequestRequestTypeDef",
+    {
+        "accountIds": Sequence[str],
+        "filters": Sequence["EBSFilterTypeDef"],
+        "fieldsToExport": Sequence[ExportableVolumeFieldType],
+        "fileFormat": Literal["Csv"],
+        "includeMemberAccounts": bool,
+    },
+    total=False,
+)
+
+
+class ExportEBSVolumeRecommendationsRequestRequestTypeDef(
+    _RequiredExportEBSVolumeRecommendationsRequestRequestTypeDef,
+    _OptionalExportEBSVolumeRecommendationsRequestRequestTypeDef,
+):
+    pass
+
 
 ExportEBSVolumeRecommendationsResponseTypeDef = TypedDict(
     "ExportEBSVolumeRecommendationsResponseTypeDef",
@@ -320,18 +372,32 @@ ExportEBSVolumeRecommendationsResponseTypeDef = TypedDict(
     },
 )
 
-ExportEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
-    "ExportEC2InstanceRecommendationsRequestRequestTypeDef",
+_RequiredExportEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
+    "_RequiredExportEC2InstanceRecommendationsRequestRequestTypeDef",
     {
         "s3DestinationConfig": "S3DestinationConfigTypeDef",
-        "accountIds": NotRequired[Sequence[str]],
-        "filters": NotRequired[Sequence["FilterTypeDef"]],
-        "fieldsToExport": NotRequired[Sequence[ExportableInstanceFieldType]],
-        "fileFormat": NotRequired[Literal["Csv"]],
-        "includeMemberAccounts": NotRequired[bool],
-        "recommendationPreferences": NotRequired["RecommendationPreferencesTypeDef"],
     },
 )
+_OptionalExportEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
+    "_OptionalExportEC2InstanceRecommendationsRequestRequestTypeDef",
+    {
+        "accountIds": Sequence[str],
+        "filters": Sequence["FilterTypeDef"],
+        "fieldsToExport": Sequence[ExportableInstanceFieldType],
+        "fileFormat": Literal["Csv"],
+        "includeMemberAccounts": bool,
+        "recommendationPreferences": "RecommendationPreferencesTypeDef",
+    },
+    total=False,
+)
+
+
+class ExportEC2InstanceRecommendationsRequestRequestTypeDef(
+    _RequiredExportEC2InstanceRecommendationsRequestRequestTypeDef,
+    _OptionalExportEC2InstanceRecommendationsRequestRequestTypeDef,
+):
+    pass
+
 
 ExportEC2InstanceRecommendationsResponseTypeDef = TypedDict(
     "ExportEC2InstanceRecommendationsResponseTypeDef",
@@ -342,17 +408,31 @@ ExportEC2InstanceRecommendationsResponseTypeDef = TypedDict(
     },
 )
 
-ExportLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
-    "ExportLambdaFunctionRecommendationsRequestRequestTypeDef",
+_RequiredExportLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
+    "_RequiredExportLambdaFunctionRecommendationsRequestRequestTypeDef",
     {
         "s3DestinationConfig": "S3DestinationConfigTypeDef",
-        "accountIds": NotRequired[Sequence[str]],
-        "filters": NotRequired[Sequence["LambdaFunctionRecommendationFilterTypeDef"]],
-        "fieldsToExport": NotRequired[Sequence[ExportableLambdaFunctionFieldType]],
-        "fileFormat": NotRequired[Literal["Csv"]],
-        "includeMemberAccounts": NotRequired[bool],
     },
 )
+_OptionalExportLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
+    "_OptionalExportLambdaFunctionRecommendationsRequestRequestTypeDef",
+    {
+        "accountIds": Sequence[str],
+        "filters": Sequence["LambdaFunctionRecommendationFilterTypeDef"],
+        "fieldsToExport": Sequence[ExportableLambdaFunctionFieldType],
+        "fileFormat": Literal["Csv"],
+        "includeMemberAccounts": bool,
+    },
+    total=False,
+)
+
+
+class ExportLambdaFunctionRecommendationsRequestRequestTypeDef(
+    _RequiredExportLambdaFunctionRecommendationsRequestRequestTypeDef,
+    _OptionalExportLambdaFunctionRecommendationsRequestRequestTypeDef,
+):
+    pass
+
 
 ExportLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
     "ExportLambdaFunctionRecommendationsResponseTypeDef",
@@ -366,21 +446,23 @@ ExportLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
 FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
-        "name": NotRequired[FilterNameType],
-        "values": NotRequired[Sequence[str]],
+        "name": FilterNameType,
+        "values": Sequence[str],
     },
+    total=False,
 )
 
 GetAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
     "GetAutoScalingGroupRecommendationsRequestRequestTypeDef",
     {
-        "accountIds": NotRequired[Sequence[str]],
-        "autoScalingGroupArns": NotRequired[Sequence[str]],
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
-        "filters": NotRequired[Sequence["FilterTypeDef"]],
-        "recommendationPreferences": NotRequired["RecommendationPreferencesTypeDef"],
+        "accountIds": Sequence[str],
+        "autoScalingGroupArns": Sequence[str],
+        "nextToken": str,
+        "maxResults": int,
+        "filters": Sequence["FilterTypeDef"],
+        "recommendationPreferences": "RecommendationPreferencesTypeDef",
     },
+    total=False,
 )
 
 GetAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
@@ -396,12 +478,13 @@ GetAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
 GetEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
     "GetEBSVolumeRecommendationsRequestRequestTypeDef",
     {
-        "volumeArns": NotRequired[Sequence[str]],
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
-        "filters": NotRequired[Sequence["EBSFilterTypeDef"]],
-        "accountIds": NotRequired[Sequence[str]],
+        "volumeArns": Sequence[str],
+        "nextToken": str,
+        "maxResults": int,
+        "filters": Sequence["EBSFilterTypeDef"],
+        "accountIds": Sequence[str],
     },
+    total=False,
 )
 
 GetEBSVolumeRecommendationsResponseTypeDef = TypedDict(
@@ -417,13 +500,14 @@ GetEBSVolumeRecommendationsResponseTypeDef = TypedDict(
 GetEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
     "GetEC2InstanceRecommendationsRequestRequestTypeDef",
     {
-        "instanceArns": NotRequired[Sequence[str]],
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
-        "filters": NotRequired[Sequence["FilterTypeDef"]],
-        "accountIds": NotRequired[Sequence[str]],
-        "recommendationPreferences": NotRequired["RecommendationPreferencesTypeDef"],
+        "instanceArns": Sequence[str],
+        "nextToken": str,
+        "maxResults": int,
+        "filters": Sequence["FilterTypeDef"],
+        "accountIds": Sequence[str],
+        "recommendationPreferences": "RecommendationPreferencesTypeDef",
     },
+    total=False,
 )
 
 GetEC2InstanceRecommendationsResponseTypeDef = TypedDict(
@@ -436,17 +520,31 @@ GetEC2InstanceRecommendationsResponseTypeDef = TypedDict(
     },
 )
 
-GetEC2RecommendationProjectedMetricsRequestRequestTypeDef = TypedDict(
-    "GetEC2RecommendationProjectedMetricsRequestRequestTypeDef",
+_RequiredGetEC2RecommendationProjectedMetricsRequestRequestTypeDef = TypedDict(
+    "_RequiredGetEC2RecommendationProjectedMetricsRequestRequestTypeDef",
     {
         "instanceArn": str,
         "stat": MetricStatisticType,
         "period": int,
         "startTime": Union[datetime, str],
         "endTime": Union[datetime, str],
-        "recommendationPreferences": NotRequired["RecommendationPreferencesTypeDef"],
     },
 )
+_OptionalGetEC2RecommendationProjectedMetricsRequestRequestTypeDef = TypedDict(
+    "_OptionalGetEC2RecommendationProjectedMetricsRequestRequestTypeDef",
+    {
+        "recommendationPreferences": "RecommendationPreferencesTypeDef",
+    },
+    total=False,
+)
+
+
+class GetEC2RecommendationProjectedMetricsRequestRequestTypeDef(
+    _RequiredGetEC2RecommendationProjectedMetricsRequestRequestTypeDef,
+    _OptionalGetEC2RecommendationProjectedMetricsRequestRequestTypeDef,
+):
+    pass
+
 
 GetEC2RecommendationProjectedMetricsResponseTypeDef = TypedDict(
     "GetEC2RecommendationProjectedMetricsResponseTypeDef",
@@ -486,10 +584,11 @@ GetEnrollmentStatusResponseTypeDef = TypedDict(
 GetEnrollmentStatusesForOrganizationRequestRequestTypeDef = TypedDict(
     "GetEnrollmentStatusesForOrganizationRequestRequestTypeDef",
     {
-        "filters": NotRequired[Sequence["EnrollmentFilterTypeDef"]],
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
+        "filters": Sequence["EnrollmentFilterTypeDef"],
+        "nextToken": str,
+        "maxResults": int,
     },
+    total=False,
 )
 
 GetEnrollmentStatusesForOrganizationResponseTypeDef = TypedDict(
@@ -504,12 +603,13 @@ GetEnrollmentStatusesForOrganizationResponseTypeDef = TypedDict(
 GetLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
     "GetLambdaFunctionRecommendationsRequestRequestTypeDef",
     {
-        "functionArns": NotRequired[Sequence[str]],
-        "accountIds": NotRequired[Sequence[str]],
-        "filters": NotRequired[Sequence["LambdaFunctionRecommendationFilterTypeDef"]],
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
+        "functionArns": Sequence[str],
+        "accountIds": Sequence[str],
+        "filters": Sequence["LambdaFunctionRecommendationFilterTypeDef"],
+        "nextToken": str,
+        "maxResults": int,
     },
+    total=False,
 )
 
 GetLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
@@ -524,21 +624,36 @@ GetLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
 GetRecommendationErrorTypeDef = TypedDict(
     "GetRecommendationErrorTypeDef",
     {
-        "identifier": NotRequired[str],
-        "code": NotRequired[str],
-        "message": NotRequired[str],
+        "identifier": str,
+        "code": str,
+        "message": str,
     },
+    total=False,
 )
 
-GetRecommendationPreferencesRequestRequestTypeDef = TypedDict(
-    "GetRecommendationPreferencesRequestRequestTypeDef",
+_RequiredGetRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "_RequiredGetRecommendationPreferencesRequestRequestTypeDef",
     {
         "resourceType": ResourceTypeType,
-        "scope": NotRequired["ScopeTypeDef"],
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
     },
 )
+_OptionalGetRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "_OptionalGetRecommendationPreferencesRequestRequestTypeDef",
+    {
+        "scope": "ScopeTypeDef",
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+
+class GetRecommendationPreferencesRequestRequestTypeDef(
+    _RequiredGetRecommendationPreferencesRequestRequestTypeDef,
+    _OptionalGetRecommendationPreferencesRequestRequestTypeDef,
+):
+    pass
+
 
 GetRecommendationPreferencesResponseTypeDef = TypedDict(
     "GetRecommendationPreferencesResponseTypeDef",
@@ -552,10 +667,11 @@ GetRecommendationPreferencesResponseTypeDef = TypedDict(
 GetRecommendationSummariesRequestRequestTypeDef = TypedDict(
     "GetRecommendationSummariesRequestRequestTypeDef",
     {
-        "accountIds": NotRequired[Sequence[str]],
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
+        "accountIds": Sequence[str],
+        "nextToken": str,
+        "maxResults": int,
     },
+    total=False,
 )
 
 GetRecommendationSummariesResponseTypeDef = TypedDict(
@@ -570,187 +686,211 @@ GetRecommendationSummariesResponseTypeDef = TypedDict(
 InstanceRecommendationOptionTypeDef = TypedDict(
     "InstanceRecommendationOptionTypeDef",
     {
-        "instanceType": NotRequired[str],
-        "projectedUtilizationMetrics": NotRequired[List["UtilizationMetricTypeDef"]],
-        "platformDifferences": NotRequired[List[PlatformDifferenceType]],
-        "performanceRisk": NotRequired[float],
-        "rank": NotRequired[int],
-        "savingsOpportunity": NotRequired["SavingsOpportunityTypeDef"],
-        "migrationEffort": NotRequired[MigrationEffortType],
+        "instanceType": str,
+        "projectedUtilizationMetrics": List["UtilizationMetricTypeDef"],
+        "platformDifferences": List[PlatformDifferenceType],
+        "performanceRisk": float,
+        "rank": int,
+        "savingsOpportunity": "SavingsOpportunityTypeDef",
+        "migrationEffort": MigrationEffortType,
     },
+    total=False,
 )
 
 InstanceRecommendationTypeDef = TypedDict(
     "InstanceRecommendationTypeDef",
     {
-        "instanceArn": NotRequired[str],
-        "accountId": NotRequired[str],
-        "instanceName": NotRequired[str],
-        "currentInstanceType": NotRequired[str],
-        "finding": NotRequired[FindingType],
-        "findingReasonCodes": NotRequired[List[InstanceRecommendationFindingReasonCodeType]],
-        "utilizationMetrics": NotRequired[List["UtilizationMetricTypeDef"]],
-        "lookBackPeriodInDays": NotRequired[float],
-        "recommendationOptions": NotRequired[List["InstanceRecommendationOptionTypeDef"]],
-        "recommendationSources": NotRequired[List["RecommendationSourceTypeDef"]],
-        "lastRefreshTimestamp": NotRequired[datetime],
-        "currentPerformanceRisk": NotRequired[CurrentPerformanceRiskType],
-        "effectiveRecommendationPreferences": NotRequired[
-            "EffectiveRecommendationPreferencesTypeDef"
-        ],
-        "inferredWorkloadTypes": NotRequired[List[InferredWorkloadTypeType]],
+        "instanceArn": str,
+        "accountId": str,
+        "instanceName": str,
+        "currentInstanceType": str,
+        "finding": FindingType,
+        "findingReasonCodes": List[InstanceRecommendationFindingReasonCodeType],
+        "utilizationMetrics": List["UtilizationMetricTypeDef"],
+        "lookBackPeriodInDays": float,
+        "recommendationOptions": List["InstanceRecommendationOptionTypeDef"],
+        "recommendationSources": List["RecommendationSourceTypeDef"],
+        "lastRefreshTimestamp": datetime,
+        "currentPerformanceRisk": CurrentPerformanceRiskType,
+        "effectiveRecommendationPreferences": "EffectiveRecommendationPreferencesTypeDef",
+        "inferredWorkloadTypes": List[InferredWorkloadTypeType],
     },
+    total=False,
 )
 
 JobFilterTypeDef = TypedDict(
     "JobFilterTypeDef",
     {
-        "name": NotRequired[JobFilterNameType],
-        "values": NotRequired[Sequence[str]],
+        "name": JobFilterNameType,
+        "values": Sequence[str],
     },
+    total=False,
 )
 
 LambdaFunctionMemoryProjectedMetricTypeDef = TypedDict(
     "LambdaFunctionMemoryProjectedMetricTypeDef",
     {
-        "name": NotRequired[Literal["Duration"]],
-        "statistic": NotRequired[LambdaFunctionMemoryMetricStatisticType],
-        "value": NotRequired[float],
+        "name": Literal["Duration"],
+        "statistic": LambdaFunctionMemoryMetricStatisticType,
+        "value": float,
     },
+    total=False,
 )
 
 LambdaFunctionMemoryRecommendationOptionTypeDef = TypedDict(
     "LambdaFunctionMemoryRecommendationOptionTypeDef",
     {
-        "rank": NotRequired[int],
-        "memorySize": NotRequired[int],
-        "projectedUtilizationMetrics": NotRequired[
-            List["LambdaFunctionMemoryProjectedMetricTypeDef"]
-        ],
-        "savingsOpportunity": NotRequired["SavingsOpportunityTypeDef"],
+        "rank": int,
+        "memorySize": int,
+        "projectedUtilizationMetrics": List["LambdaFunctionMemoryProjectedMetricTypeDef"],
+        "savingsOpportunity": "SavingsOpportunityTypeDef",
     },
+    total=False,
 )
 
 LambdaFunctionRecommendationFilterTypeDef = TypedDict(
     "LambdaFunctionRecommendationFilterTypeDef",
     {
-        "name": NotRequired[LambdaFunctionRecommendationFilterNameType],
-        "values": NotRequired[Sequence[str]],
+        "name": LambdaFunctionRecommendationFilterNameType,
+        "values": Sequence[str],
     },
+    total=False,
 )
 
 LambdaFunctionRecommendationTypeDef = TypedDict(
     "LambdaFunctionRecommendationTypeDef",
     {
-        "functionArn": NotRequired[str],
-        "functionVersion": NotRequired[str],
-        "accountId": NotRequired[str],
-        "currentMemorySize": NotRequired[int],
-        "numberOfInvocations": NotRequired[int],
-        "utilizationMetrics": NotRequired[List["LambdaFunctionUtilizationMetricTypeDef"]],
-        "lookbackPeriodInDays": NotRequired[float],
-        "lastRefreshTimestamp": NotRequired[datetime],
-        "finding": NotRequired[LambdaFunctionRecommendationFindingType],
-        "findingReasonCodes": NotRequired[List[LambdaFunctionRecommendationFindingReasonCodeType]],
-        "memorySizeRecommendationOptions": NotRequired[
-            List["LambdaFunctionMemoryRecommendationOptionTypeDef"]
-        ],
-        "currentPerformanceRisk": NotRequired[CurrentPerformanceRiskType],
+        "functionArn": str,
+        "functionVersion": str,
+        "accountId": str,
+        "currentMemorySize": int,
+        "numberOfInvocations": int,
+        "utilizationMetrics": List["LambdaFunctionUtilizationMetricTypeDef"],
+        "lookbackPeriodInDays": float,
+        "lastRefreshTimestamp": datetime,
+        "finding": LambdaFunctionRecommendationFindingType,
+        "findingReasonCodes": List[LambdaFunctionRecommendationFindingReasonCodeType],
+        "memorySizeRecommendationOptions": List["LambdaFunctionMemoryRecommendationOptionTypeDef"],
+        "currentPerformanceRisk": CurrentPerformanceRiskType,
     },
+    total=False,
 )
 
 LambdaFunctionUtilizationMetricTypeDef = TypedDict(
     "LambdaFunctionUtilizationMetricTypeDef",
     {
-        "name": NotRequired[LambdaFunctionMetricNameType],
-        "statistic": NotRequired[LambdaFunctionMetricStatisticType],
-        "value": NotRequired[float],
+        "name": LambdaFunctionMetricNameType,
+        "statistic": LambdaFunctionMetricStatisticType,
+        "value": float,
     },
+    total=False,
 )
 
 ProjectedMetricTypeDef = TypedDict(
     "ProjectedMetricTypeDef",
     {
-        "name": NotRequired[MetricNameType],
-        "timestamps": NotRequired[List[datetime]],
-        "values": NotRequired[List[float]],
+        "name": MetricNameType,
+        "timestamps": List[datetime],
+        "values": List[float],
     },
+    total=False,
 )
 
-PutRecommendationPreferencesRequestRequestTypeDef = TypedDict(
-    "PutRecommendationPreferencesRequestRequestTypeDef",
+_RequiredPutRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "_RequiredPutRecommendationPreferencesRequestRequestTypeDef",
     {
         "resourceType": ResourceTypeType,
-        "scope": NotRequired["ScopeTypeDef"],
-        "enhancedInfrastructureMetrics": NotRequired[EnhancedInfrastructureMetricsType],
-        "inferredWorkloadTypes": NotRequired[InferredWorkloadTypesPreferenceType],
     },
 )
+_OptionalPutRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "_OptionalPutRecommendationPreferencesRequestRequestTypeDef",
+    {
+        "scope": "ScopeTypeDef",
+        "enhancedInfrastructureMetrics": EnhancedInfrastructureMetricsType,
+        "inferredWorkloadTypes": InferredWorkloadTypesPreferenceType,
+    },
+    total=False,
+)
+
+
+class PutRecommendationPreferencesRequestRequestTypeDef(
+    _RequiredPutRecommendationPreferencesRequestRequestTypeDef,
+    _OptionalPutRecommendationPreferencesRequestRequestTypeDef,
+):
+    pass
+
 
 ReasonCodeSummaryTypeDef = TypedDict(
     "ReasonCodeSummaryTypeDef",
     {
-        "name": NotRequired[FindingReasonCodeType],
-        "value": NotRequired[float],
+        "name": FindingReasonCodeType,
+        "value": float,
     },
+    total=False,
 )
 
 RecommendationExportJobTypeDef = TypedDict(
     "RecommendationExportJobTypeDef",
     {
-        "jobId": NotRequired[str],
-        "destination": NotRequired["ExportDestinationTypeDef"],
-        "resourceType": NotRequired[ResourceTypeType],
-        "status": NotRequired[JobStatusType],
-        "creationTimestamp": NotRequired[datetime],
-        "lastUpdatedTimestamp": NotRequired[datetime],
-        "failureReason": NotRequired[str],
+        "jobId": str,
+        "destination": "ExportDestinationTypeDef",
+        "resourceType": ResourceTypeType,
+        "status": JobStatusType,
+        "creationTimestamp": datetime,
+        "lastUpdatedTimestamp": datetime,
+        "failureReason": str,
     },
+    total=False,
 )
 
 RecommendationPreferencesDetailTypeDef = TypedDict(
     "RecommendationPreferencesDetailTypeDef",
     {
-        "scope": NotRequired["ScopeTypeDef"],
-        "resourceType": NotRequired[ResourceTypeType],
-        "enhancedInfrastructureMetrics": NotRequired[EnhancedInfrastructureMetricsType],
-        "inferredWorkloadTypes": NotRequired[InferredWorkloadTypesPreferenceType],
+        "scope": "ScopeTypeDef",
+        "resourceType": ResourceTypeType,
+        "enhancedInfrastructureMetrics": EnhancedInfrastructureMetricsType,
+        "inferredWorkloadTypes": InferredWorkloadTypesPreferenceType,
     },
+    total=False,
 )
 
 RecommendationPreferencesTypeDef = TypedDict(
     "RecommendationPreferencesTypeDef",
     {
-        "cpuVendorArchitectures": NotRequired[Sequence[CpuVendorArchitectureType]],
+        "cpuVendorArchitectures": Sequence[CpuVendorArchitectureType],
     },
+    total=False,
 )
 
 RecommendationSourceTypeDef = TypedDict(
     "RecommendationSourceTypeDef",
     {
-        "recommendationSourceArn": NotRequired[str],
-        "recommendationSourceType": NotRequired[RecommendationSourceTypeType],
+        "recommendationSourceArn": str,
+        "recommendationSourceType": RecommendationSourceTypeType,
     },
+    total=False,
 )
 
 RecommendationSummaryTypeDef = TypedDict(
     "RecommendationSummaryTypeDef",
     {
-        "summaries": NotRequired[List["SummaryTypeDef"]],
-        "recommendationResourceType": NotRequired[RecommendationSourceTypeType],
-        "accountId": NotRequired[str],
-        "savingsOpportunity": NotRequired["SavingsOpportunityTypeDef"],
-        "currentPerformanceRiskRatings": NotRequired["CurrentPerformanceRiskRatingsTypeDef"],
+        "summaries": List["SummaryTypeDef"],
+        "recommendationResourceType": RecommendationSourceTypeType,
+        "accountId": str,
+        "savingsOpportunity": "SavingsOpportunityTypeDef",
+        "currentPerformanceRiskRatings": "CurrentPerformanceRiskRatingsTypeDef",
     },
+    total=False,
 )
 
 RecommendedOptionProjectedMetricTypeDef = TypedDict(
     "RecommendedOptionProjectedMetricTypeDef",
     {
-        "recommendedInstanceType": NotRequired[str],
-        "rank": NotRequired[int],
-        "projectedMetrics": NotRequired[List["ProjectedMetricTypeDef"]],
+        "recommendedInstanceType": str,
+        "rank": int,
+        "projectedMetrics": List["ProjectedMetricTypeDef"],
     },
+    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -767,52 +907,71 @@ ResponseMetadataTypeDef = TypedDict(
 S3DestinationConfigTypeDef = TypedDict(
     "S3DestinationConfigTypeDef",
     {
-        "bucket": NotRequired[str],
-        "keyPrefix": NotRequired[str],
+        "bucket": str,
+        "keyPrefix": str,
     },
+    total=False,
 )
 
 S3DestinationTypeDef = TypedDict(
     "S3DestinationTypeDef",
     {
-        "bucket": NotRequired[str],
-        "key": NotRequired[str],
-        "metadataKey": NotRequired[str],
+        "bucket": str,
+        "key": str,
+        "metadataKey": str,
     },
+    total=False,
 )
 
 SavingsOpportunityTypeDef = TypedDict(
     "SavingsOpportunityTypeDef",
     {
-        "savingsOpportunityPercentage": NotRequired[float],
-        "estimatedMonthlySavings": NotRequired["EstimatedMonthlySavingsTypeDef"],
+        "savingsOpportunityPercentage": float,
+        "estimatedMonthlySavings": "EstimatedMonthlySavingsTypeDef",
     },
+    total=False,
 )
 
 ScopeTypeDef = TypedDict(
     "ScopeTypeDef",
     {
-        "name": NotRequired[ScopeNameType],
-        "value": NotRequired[str],
+        "name": ScopeNameType,
+        "value": str,
     },
+    total=False,
 )
 
 SummaryTypeDef = TypedDict(
     "SummaryTypeDef",
     {
-        "name": NotRequired[FindingType],
-        "value": NotRequired[float],
-        "reasonCodeSummaries": NotRequired[List["ReasonCodeSummaryTypeDef"]],
+        "name": FindingType,
+        "value": float,
+        "reasonCodeSummaries": List["ReasonCodeSummaryTypeDef"],
     },
+    total=False,
 )
 
-UpdateEnrollmentStatusRequestRequestTypeDef = TypedDict(
-    "UpdateEnrollmentStatusRequestRequestTypeDef",
+_RequiredUpdateEnrollmentStatusRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateEnrollmentStatusRequestRequestTypeDef",
     {
         "status": StatusType,
-        "includeMemberAccounts": NotRequired[bool],
     },
 )
+_OptionalUpdateEnrollmentStatusRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateEnrollmentStatusRequestRequestTypeDef",
+    {
+        "includeMemberAccounts": bool,
+    },
+    total=False,
+)
+
+
+class UpdateEnrollmentStatusRequestRequestTypeDef(
+    _RequiredUpdateEnrollmentStatusRequestRequestTypeDef,
+    _OptionalUpdateEnrollmentStatusRequestRequestTypeDef,
+):
+    pass
+
 
 UpdateEnrollmentStatusResponseTypeDef = TypedDict(
     "UpdateEnrollmentStatusResponseTypeDef",
@@ -826,45 +985,49 @@ UpdateEnrollmentStatusResponseTypeDef = TypedDict(
 UtilizationMetricTypeDef = TypedDict(
     "UtilizationMetricTypeDef",
     {
-        "name": NotRequired[MetricNameType],
-        "statistic": NotRequired[MetricStatisticType],
-        "value": NotRequired[float],
+        "name": MetricNameType,
+        "statistic": MetricStatisticType,
+        "value": float,
     },
+    total=False,
 )
 
 VolumeConfigurationTypeDef = TypedDict(
     "VolumeConfigurationTypeDef",
     {
-        "volumeType": NotRequired[str],
-        "volumeSize": NotRequired[int],
-        "volumeBaselineIOPS": NotRequired[int],
-        "volumeBurstIOPS": NotRequired[int],
-        "volumeBaselineThroughput": NotRequired[int],
-        "volumeBurstThroughput": NotRequired[int],
+        "volumeType": str,
+        "volumeSize": int,
+        "volumeBaselineIOPS": int,
+        "volumeBurstIOPS": int,
+        "volumeBaselineThroughput": int,
+        "volumeBurstThroughput": int,
     },
+    total=False,
 )
 
 VolumeRecommendationOptionTypeDef = TypedDict(
     "VolumeRecommendationOptionTypeDef",
     {
-        "configuration": NotRequired["VolumeConfigurationTypeDef"],
-        "performanceRisk": NotRequired[float],
-        "rank": NotRequired[int],
-        "savingsOpportunity": NotRequired["SavingsOpportunityTypeDef"],
+        "configuration": "VolumeConfigurationTypeDef",
+        "performanceRisk": float,
+        "rank": int,
+        "savingsOpportunity": "SavingsOpportunityTypeDef",
     },
+    total=False,
 )
 
 VolumeRecommendationTypeDef = TypedDict(
     "VolumeRecommendationTypeDef",
     {
-        "volumeArn": NotRequired[str],
-        "accountId": NotRequired[str],
-        "currentConfiguration": NotRequired["VolumeConfigurationTypeDef"],
-        "finding": NotRequired[EBSFindingType],
-        "utilizationMetrics": NotRequired[List["EBSUtilizationMetricTypeDef"]],
-        "lookBackPeriodInDays": NotRequired[float],
-        "volumeRecommendationOptions": NotRequired[List["VolumeRecommendationOptionTypeDef"]],
-        "lastRefreshTimestamp": NotRequired[datetime],
-        "currentPerformanceRisk": NotRequired[CurrentPerformanceRiskType],
+        "volumeArn": str,
+        "accountId": str,
+        "currentConfiguration": "VolumeConfigurationTypeDef",
+        "finding": EBSFindingType,
+        "utilizationMetrics": List["EBSUtilizationMetricTypeDef"],
+        "lookBackPeriodInDays": float,
+        "volumeRecommendationOptions": List["VolumeRecommendationOptionTypeDef"],
+        "lastRefreshTimestamp": datetime,
+        "currentPerformanceRisk": CurrentPerformanceRiskType,
     },
+    total=False,
 )
